@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2012-2019 Montel Laurent <montel@kde.org>
+   Copyright (C) 2012-2020 Laurent Montel <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -20,7 +20,7 @@
 #ifndef UPDATECONTACTJOB_H
 #define UPDATECONTACTJOB_H
 
-#include <kjob.h>
+#include <KJob>
 
 #include <KContacts/Addressee>
 
