@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2019 Laurent Montel <montel@kde.org>
+   Copyright (C) 2019-2020 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -34,8 +34,11 @@ public:
     void saveSettings();
     void resetSettings();
 private:
+    void slotConfigureAuthenticationServer();
     QComboBox *mSha1Policy = nullptr;
     QCheckBox *mCheckDKIMWhenOnlyTesting = nullptr;
+    QCheckBox *mUseAuthenticationResultRelaxedParser = nullptr;
+    QComboBox *mSmallKeyPolicy = nullptr;
 };
 
 #endif // DKIMADVANCEDWIDGET_H
