@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2018-2019 Montel Laurent <montel@kde.org>
+   Copyright (C) 2018-2020 Laurent Montel <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -19,7 +19,7 @@
 
 #include "dkimconfiguresettingsplugin.h"
 #include "dkimconfiguredialog.h"
-#include <kpluginfactory.h>
+#include <KPluginFactory>
 
 K_PLUGIN_CLASS_WITH_JSON(DkimConfigureSettingsPlugin, "messageviewer_dkimconfigplugin.json")
 
