@@ -68,7 +68,8 @@ void ViewerPluginCreatenoteInterface::closePlugin()
 Akonadi::Relation ViewerPluginCreatenoteInterface::relatedNoteRelation() const
 {
     Akonadi::Relation relation;
-    for (const Akonadi::Relation &r : mMessageItem.relations()) {
+    const auto relations = mMessageItem.relations();
+    for (const Akonadi::Relation &r : relations) {
         // assuming that GENERIC relations to emails are notes is a pretty horrific hack imo - aseigo
         if (r.type() == Akonadi::Relation::GENERIC && r.right().mimeType() == Akonadi::NoteUtils::noteMimeType()) {
             relation = r;
