@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2016-2019 Montel Laurent <montel@kde.org>
+   Copyright (C) 2016-2020 Laurent Montel <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -72,7 +72,11 @@ void AdBlockAutomaticRulesListWidget::setDisabledRules(const QStringList &disabl
 void AdBlockAutomaticRulesListWidget::setRules(const QString &rules)
 {
     clear();
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
     const QStringList lst = rules.split(QLatin1Char('\n'), QString::SkipEmptyParts);
+#else
+    const QStringList lst = rules.split(QLatin1Char('\n'), Qt::SkipEmptyParts);
+#endif
     for (const QString &rule : lst) {
         createItem(rule);
     }
