@@ -35,10 +35,10 @@
 #include "adblockmanager.h"
 #include "adblockshowlistdialog.h"
 #include "adblockutil.h"
-#include "PimCommon/ConfigureImmutableWidgetUtils"
+#include <PimCommon/ConfigureImmutableWidgetUtils>
 using namespace PimCommon::ConfigureImmutableWidgetUtils;
 
-#include "PimCommon/PimUtil"
+#include <PimCommon/PimUtil>
 
 // KDE Includes
 #include <KSharedConfig>
@@ -54,7 +54,9 @@ using namespace PimCommon::ConfigureImmutableWidgetUtils;
 #include <QListWidgetItem>
 #include <QPointer>
 #include <QStandardPaths>
-#include <KRun>
+#include <kio_version.h>
+#include <KIO/JobUiDelegate>
+#include <KIO/OpenUrlJob>
 #include <adblocksubscription.h>
 
 using namespace AdBlock;
@@ -168,7 +170,9 @@ bool AdBlockSettingWidget::event(QEvent *event)
 {
     if (event->type() == QEvent::WhatsThisClicked) {
         QWhatsThisClickedEvent *clicked = static_cast<QWhatsThisClickedEvent *>(event);
-        new KRun(QUrl(clicked->href()), this);
+        KIO::OpenUrlJob *job = new KIO::OpenUrlJob(QUrl(clicked->href()));
+        job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, this));
+        job->start();
         return true;
     }
     return QWidget::event(event);
